@@ -52,9 +52,15 @@ replace_paragraph_role = \
               'sup' : '',
               'tablecontent': '| | ',
               'tablecontentcode': '| | <code>',
+              'tablecontentnote': '| |{{Note|',
+              'tablecontenttip': '| |{{Tip|',
+              'tablecontentwarning': '| |{{Warning|',
               'tablehead': '! scope="col" | ',
+              'tablenextnote': '\n{{Note|',
               'tablenextpara': '\n',
               'tablenextparacode': '\n<code>',
+              'tablenexttip': '\n{{Tip|',
+              'tablenextwarning': '\n{{Warning|',
               'tip': '{{Tip|',
               'variable': '',
               'warning': '{{Warning|',
@@ -82,9 +88,15 @@ replace_paragraph_role = \
             'sup' : '',
             'tablecontent': '\n',
             'tablecontentcode': '</code>\n',
+            'tablecontentnote': '}}\n\n',
+            'tablecontenttip': '}}\n\n',
+            'tablecontentwarning': '}}\n\n',
             'tablehead': '\n',
+            'tablenextnote': '}}\n\n',
             'tablenextpara': '\n',
             'tablenextparacode': '</code>\n',
+            'tablenexttip': '}}\n\n',
+            'tablenextwarning': '}}\n\n',
             'tip': '}}\n\n',
             'variable': '',
             'warning': '}}\n\n',
@@ -112,9 +124,15 @@ replace_paragraph_role = \
               'sup' : False,
               'tablecontent': False,
               'tablecontentcode': False,
+              'tablecontentnote': True,
+              'tablecontenttip': True,
+              'tablecontentwarning': True,
               'tablehead': False,
+              'tablenextnote': True,
               'tablenextpara': False,
               'tablenextparacode': False,
+              'tablenexttip': True,
+              'tablenextwarning': True,
               'tip': True,
               'variable': False,
               'warning': True,
@@ -418,7 +436,7 @@ class XhpFile(ElementBase):
             # ignored, we flatten the structure
             pass
         elif name == 'list':
-            self.parse_child(List(attrs, self))
+            self.parse_child(List(attrs, self, False))
         elif name == 'meta':
             self.parse_child(Meta(attrs, self))
         elif name == 'paragraph':
@@ -558,6 +576,8 @@ class TableCell(ElementBase):
         elif name == 'bascode':
             # ignored, do not syntax highlight in table cells
             pass
+        elif name == 'list':
+            self.parse_child(List(attrs, self, True))
         else:
             self.unhandled_element(parser, name)
 
@@ -578,6 +598,7 @@ class TableRow(ElementBase):
         ElementBase.__init__(self, 'tablerow', parent)
 
     def start_element(self, parser, name, attrs):
+        self.isTableHeader = False
         if name == 'tablecell':
             self.parse_child(TableCell(attrs, self))
         else:
@@ -634,7 +655,7 @@ class ListItem(ElementBase):
         elif name == 'paragraph':
             parser.parse_localized_paragraph(ListItemParagraph, attrs, self)
         elif name == 'list':
-            self.parse_child(List(attrs, self))
+            self.parse_child(List(attrs, self, False))
         else:
             self.unhandled_element(parser, name)
 
@@ -658,9 +679,10 @@ class ListItem(ElementBase):
         return text + postfix
 
 class List(ElementBase):
-    def __init__(self, attrs, parent):
+    def __init__(self, attrs, parent, isInTable):
         ElementBase.__init__(self, 'list', parent)
 
+        self.isInTable = isInTable
         self.type = attrs['type']
         try:
             self.startwith = int(attrs['startwith'])
@@ -675,6 +697,8 @@ class List(ElementBase):
 
     def get_all(self):
         text = ""
+        if self.isInTable:
+            text = '| |\n'
         if self.startwith > 0:
             text = text + '<ol start="%d">\n'% self.startwith
 
@@ -747,7 +771,7 @@ class Section(ElementBase):
             if parser.follow_embed:
                 self.embed_href(parser, fname, id)
         elif name == 'list':
-            self.parse_child(List(attrs, self))
+            self.parse_child(List(attrs, self, False))
         elif name == 'paragraph':
             parser.parse_paragraph(attrs, self)
         elif name == 'section':
@@ -939,13 +963,15 @@ class Case(ElementBase):
                 (fname, id) = href_to_fname_id(attrs['href'])
                 self.embed_href(parser, fname, id)
         elif name == 'list':
-            self.parse_child(List(attrs, self))
+            self.parse_child(List(attrs, self, False))
         elif name == 'paragraph':
             parser.parse_paragraph(attrs, self)
         elif name == 'section':
             self.parse_child(Section(attrs, self))
         elif name == 'table':
             self.parse_child(Table(attrs, self))
+        elif name == 'bascode':
+            self.parse_child(BasicCode(attrs, self))
         else:
             self.unhandled_element(parser, name)
 
@@ -1114,6 +1140,12 @@ class Paragraph(ElementBase):
         if not self.is_first and role.find('table') == 0:
             if role == 'tablecontentcode':
                 role = 'tablenextparacode'
+            elif role == 'tablecontentnote':
+                role = 'tablenextnote'
+            elif role == 'tablecontenttip':
+                role = 'tablenexttip'
+            elif role == 'tablecontentwarning':
+                role = 'tablenextwarning'
             else:
                 role = 'tablenextpara'
 
@@ -1216,6 +1248,12 @@ class TableContentParagraph(Paragraph):
                 self.role = 'tablecontentcode'
             elif self.role == 'logocode':
                 self.role = 'tablecontentcode'
+            elif self.role == 'note':
+                self.role = 'tablecontentnote'
+            elif self.role == 'tip':
+                self.role = 'tablecontenttip'
+            elif self.role == 'warning':
+                self.role = 'tablecontentwarning'
             else:
                 self.role = 'tablecontent'
         if self.role == 'tablehead':
@@ -1272,7 +1310,7 @@ class ParserBase:
                         paragraph, text.encode('utf-8'))
             except xml.parsers.expat.ExpatError:
                 sys.stderr.write( 'Invalid XML in translated text. Using the original text. Error location:\n'\
-                                  + 'Curren xhp: ' + self.filename + '\nParagraph id: ' + attrs['id'] + '\n')
+                                  + 'Current xhp: ' + self.filename + '\nParagraph id: ' + attrs['id'] + '\n')
                 obj.parse_child(Paragraph_type(attrs, obj)) # new paragraph must be created because "paragraph" is corrupted by "ParserBase"
             else:
                 # add it to the overall structure
@@ -1367,7 +1405,7 @@ def write_redirects():
         redirect = redir[1]
         target = redir[2]
         authoritative = redir[3]
-    
+
         if app != '':
             r = '%s/%s'% (app, redirect)
             if authoritative:
@@ -1378,13 +1416,13 @@ def write_redirects():
                     written[r]
                 except:
                     written[r] = False
-    
+
     # in the second pass, output the wiki links
     for redir in redirects:
         app = redir[0]
         redirect = redir[1]
         target = redir[2]
-    
+
         if app == '':
             for i in ['swriter', 'scalc', 'simpress', 'sdraw', 'smath', \
                       'schart', 'sbasic', 'sdatabase']:
@@ -1416,7 +1454,7 @@ def convert(generate_redirects, lang, po_root):
     for title in titles:
         while threading.active_count() > max_threads:
             time.sleep(0.001)
-    
+
         infile = title[0].strip()
         wikiname = title[1].strip()
         articledir = 'wiki/' + wikiname
@@ -1444,7 +1482,7 @@ def convert(generate_redirects, lang, po_root):
                         (infile, outfile)
         sys.stderr.write('Warning: Skipping: %s > %s\n'% (infile, outfile))
         file.close()
-    
+
     # wait for everyone to finish
     while threading.active_count() > 1:
         time.sleep(0.001)
